Class: Kompo::InstallRuby

Inherits:
Taski::Section
  • Object
show all
Defined in:
lib/kompo/tasks/install_ruby.rb

Overview

Section to install static Ruby Switches between cache restore and building from source Required context:

- ruby_version: Ruby version to build (default: current RUBY_VERSION)
- kompo_cache: Cache directory for kompo (default: ~/.kompo/cache)
- clear_cache: If true, clear the Ruby build cache before building

Defined Under Namespace

Classes: FromCache, FromSource

Constant Summary collapse

STATIC_EXTENSIONS =

Ruby extensions to build statically

%w[
  bigdecimal
  cgi/escape
  continuation
  coverage
  date
  digest/bubblebabble
  digest
  digest/md5
  digest/rmd160
  digest/sha1
  digest/sha2
  etc
  fcntl
  fiddle
  io/console
  io/nonblock
  io/wait
  json
  json/generator
  json/parser
  nkf
  monitor
  objspace
  openssl
  pathname
  psych
  pty
  racc/cparse
  rbconfig/sizeof
  readline
  ripper
  socket
  stringio
  strscan
  syslog
  zlib
].freeze

Instance Method Summary collapse

Instance Method Details

#implObject



19
20
21
22
23
24
# File 'lib/kompo/tasks/install_ruby.rb', line 19

def impl
  # Skip cache if --no-cache is specified, or if cache doesn't exist
  return FromSource if Taski.args[:no_cache]

  cache_exists? ? FromCache : FromSource
end